<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

/**
 * Check if hero content is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_hero_content_is_enable( $control ) {
	$enable_hero_content = $control->manager->get_setting( 'pikture_pro_theme_options[enable_hero_content]' )->value();

	return ( 'front-page' === $enable_hero_content || 'entire-site' === $enable_hero_content );
}

/**
 * Check if featured content is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_featured_content_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_featured_section]' )->value();
}

/**
 * Check if featured section content type  is custom.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_featured_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[featured_content_type]' )->value();
	return pikture_pro_is_featured_content_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if featured section content type  is pagge.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_featured_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[featured_content_type]' )->value();
	return pikture_pro_is_featured_content_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if featured section content type  is post.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_featured_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[featured_content_type]' )->value();
	return pikture_pro_is_featured_content_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if counter section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_counter_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_counter_section]' )->value();
}

/**
 * Check if about section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_about_section]' )->value();
}

/**
 * Check if about section content type custom is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_custom_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_content_type]' )->value();
	return pikture_pro_is_about_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if about section content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_page_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_content_type]' )->value();
	return pikture_pro_is_about_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if about section content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_post_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_content_type]' )->value();
	return pikture_pro_is_about_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if about section content type demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_demo_content_disabled( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_content_type]' )->value();
	return pikture_pro_is_about_enable( $control ) && ( 'demo' != $content_type );
}

/**
 * Check if panorama section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_panorama_section]' )->value();
}

/**
 * Check if panorama section content is gallery.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_content_gallery_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[panorama_content_type]' )->value();
	return pikture_pro_is_panorama_enable( $control ) && ( 'gallery' === $content_type );
}

/**
 * Check if panorama section content is category.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[panorama_content_type]' )->value();
	return pikture_pro_is_panorama_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if panorama section content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[panorama_content_type]' )->value();
	return pikture_pro_is_panorama_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if panorama section content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[panorama_content_type]' )->value();
	return pikture_pro_is_panorama_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if panorama section content type post or page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_content_post_page_enable( $control ) {
	return pikture_pro_is_panorama_content_post_enable( $control ) || pikture_pro_is_panorama_content_page_enable( $control ) || pikture_pro_is_panorama_content_category_enable( $control );
}

/**
 * Check if panorama section content type demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_content_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[panorama_content_type]' )->value();
	return  ( 'demo' != $content_type ) && pikture_pro_is_panorama_enable( $control );
}


/**
 * Check if panorama section content type cat or demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_panorama_content_cat_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[panorama_content_type]' )->value();
	return  ( 'category' != $content_type && 'demo' != $content_type ) && pikture_pro_is_panorama_enable( $control );
}

/**
 * Check if call_to_action section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_call_to_action_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_call_to_action_section]' )->value();
}

/**
 * Check if call to action section content type custom is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_call_to_action_custom_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[call_to_action_content_type]' )->value();
	return pikture_pro_is_call_to_action_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if call to action section content type demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_call_to_action_content_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[call_to_action_content_type]' )->value();
	return  ( 'demo' != $content_type ) && pikture_pro_is_call_to_action_enable( $control );
}

/**
 * Check if call to action section content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_call_to_action_page_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[call_to_action_content_type]' )->value();
	return pikture_pro_is_call_to_action_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if call to action section content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_call_to_action_post_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[call_to_action_content_type]' )->value();
	return pikture_pro_is_call_to_action_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if portrait section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_portrait_section]' )->value();
}

/**
 * Check if portrait section content is gallery.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_content_gallery_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[portrait_content_type]' )->value();
	return pikture_pro_is_portrait_enable( $control ) && ( 'gallery' === $content_type );
}

/**
 * Check if portrait section content is category.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[portrait_content_type]' )->value();
	return pikture_pro_is_portrait_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if portrait section content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[portrait_content_type]' )->value();
	return pikture_pro_is_portrait_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if portrait section content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[portrait_content_type]' )->value();
	return pikture_pro_is_portrait_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if portrait section content type demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_content_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[portrait_content_type]' )->value();
	return  ( 'demo' != $content_type ) && pikture_pro_is_portrait_enable( $control );
}

/**
 * Check if portrait section content type cat, page or demo is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_content_cat_post_page_enable( $control ) {
	return pikture_pro_is_portrait_content_post_enable( $control ) || pikture_pro_is_portrait_content_page_enable( $control ) || pikture_pro_is_portrait_content_category_enable( $control );
}

/**
 * Check if portrait section content type cat or demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_portrait_content_cat_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[portrait_content_type]' )->value();
	return  ( 'category' != $content_type && 'demo' != $content_type ) && pikture_pro_is_portrait_enable( $control );
}

/**
 * Check if client section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_client_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_client_section]' )->value();
}

/**
 * Check if client section content is custom.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_client_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[client_content_type]' )->value();
	return pikture_pro_is_client_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if client section content is custom.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_client_content_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[client_content_type]' )->value();
	return pikture_pro_is_client_enable( $control ) && ( 'demo' != $content_type );
}

/**
 * Check if client section content is page.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_client_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[client_content_type]' )->value();
	return pikture_pro_is_client_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if client section content is post.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_client_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[client_content_type]' )->value();
	return pikture_pro_is_client_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if client section content is category.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_client_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[client_content_type]' )->value();
	return pikture_pro_is_client_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if landscape section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_landscape_section]' )->value();
}

/**
 * Check if landscape section content is gallery.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_content_gallery_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[landscape_content_type]' )->value();
	return pikture_pro_is_landscape_enable( $control ) && ( 'gallery' === $content_type );
}

/**
 * Check if landscape section content is category.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[landscape_content_type]' )->value();
	return pikture_pro_is_landscape_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if landscape section content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[landscape_content_type]' )->value();
	return pikture_pro_is_landscape_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if landscape section content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[landscape_content_type]' )->value();
	return pikture_pro_is_landscape_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if landscape section content type post or page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_content_cat_post_page_enable( $control ) {
	return pikture_pro_is_landscape_content_post_enable( $control ) || pikture_pro_is_landscape_content_page_enable( $control ) || pikture_pro_is_landscape_content_category_enable( $control );
}

/**
 * Check if landscape section content type demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_content_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[landscape_content_type]' )->value();
	return  ( 'demo' != $content_type ) && pikture_pro_is_landscape_enable( $control );
}


/**
 * Check if landscape section content type cat or demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_landscape_content_cat_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[landscape_content_type]' )->value();
	return  ( 'category' != $content_type && 'demo' != $content_type ) && pikture_pro_is_landscape_enable( $control );
}

/**
 * Check if testimonial is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_testimonial_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_testimonial_section]' )->value();
}

/**
 * Check if testimonial left part is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_testimonial_left_part_enable( $control ) {
	return ( $control->manager->get_setting( 'pikture_pro_theme_options[enable_testimonial_left_part]' )->value() && $control->manager->get_setting( 'pikture_pro_theme_options[enable_testimonial_section]' )->value() );
}

/**
 * Check if testimonial section content is category.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_testimonial_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[testimonial_content_type]' )->value();
	return pikture_pro_is_testimonial_enable( $control ) && ( 'category' === $content_type );
}

/**
 * Check if panorama section content type post or page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_testimonial_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[testimonial_content_type]' )->value();
	return pikture_pro_is_testimonial_enable( $control ) && ( 'demo' != $content_type );
}

/**
 * Check if testimonial section content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_testimonial_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[testimonial_content_type]' )->value();
	return pikture_pro_is_testimonial_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if testimonial section content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_testimonial_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[testimonial_content_type]' )->value();
	return pikture_pro_is_testimonial_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if testimonial section content type custom is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_testimonial_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[testimonial_content_type]' )->value();
	return pikture_pro_is_testimonial_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if about slider content is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_slider_content_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_about_temp_slider]' )->value();
}

/**
 * Check if about slider content demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_slider_content_demo_disable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_slider_content_type]' )->value();
	return pikture_pro_is_about_temp_slider_content_enable( $control ) && ( 'demo' != $content_type );
}

/**
 * Check if about slider content type custom is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_slider_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_slider_content_type]' )->value();
	return pikture_pro_is_about_temp_slider_content_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if about slider content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_slider_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_slider_content_type]' )->value();
	return pikture_pro_is_about_temp_slider_content_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if about slider content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_slider_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_slider_content_type]' )->value();
	return pikture_pro_is_about_temp_slider_content_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if about counter content is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_counter_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_about_temp_counter]' )->value();
}

/**
 * Check if about portfolio section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_portfolio_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_about_temp_portfolio_section]' )->value();
}

/**
 * Check if about portfolio section content type custom is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_portfolio_custom_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_portfolio_content_type]' )->value();
	return pikture_pro_is_about_temp_portfolio_enable( $control ) && ( 'custom' === $content_type );
}

/**
 * Check if about portfolio section content type page is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_portfolio_page_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_portfolio_content_type]' )->value();
	return pikture_pro_is_about_temp_portfolio_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if about portfolio section content type post is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_portfolio_post_content_enable( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_portfolio_content_type]' )->value();
	return pikture_pro_is_about_temp_portfolio_enable( $control ) && ( 'post' === $content_type );
}

/**
 * Check if about portfolio section content type demo is disabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_portfolio_demo_content_disabled( $control ) {
	$content_type = $control->manager->get_setting( 'pikture_pro_theme_options[about_temp_portfolio_content_type]' )->value();
	return pikture_pro_is_about_temp_portfolio_enable( $control ) && ( 'demo' != $content_type );
}

/**
 * Check if about template contact section is enabled.
 *
 * @since Pikture Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function pikture_pro_is_about_temp_contact_enable( $control ) {
	return $control->manager->get_setting( 'pikture_pro_theme_options[enable_about_temp_contact]' )->value();
}

if ( ! function_exists( 'pikture_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Pikture Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pikture_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'pikture_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'pikture_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Pikture Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pikture_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'pikture_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'pikture_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Pikture Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pikture_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'pikture_pro_theme_options[pagination_enable]' )->value();
	}
endif;

if ( ! function_exists( 'pikture_pro_if_homepage_displays_static_page' ) ) :
	/**
	 * Check if Homepage setting is set to display static page.
	 *
	 * @since Pikture Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pikture_pro_if_homepage_displays_static_page( $control ) {
		return ( 'page' === get_option( 'show_on_front' ) );
	}
endif;

if ( ! function_exists( 'pikture_pro_if_homepage_displays_latest_posts' ) ) :
	/**
	 * Check if Homepage setting is set to display latest posts.
	 *
	 * @since Pikture Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pikture_pro_if_homepage_displays_latest_posts( $control ) {
		return ( 'posts' === get_option( 'show_on_front' ) );
	}
endif;

if ( ! function_exists( 'pikture_pro_is_modern_menu_active' ) ) :
	/**
	 * Check if modern menu is enabled.
	 *
	 * @since Pikture Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function pikture_pro_is_modern_menu_active( $control ) {
		return 'modern' === $control->manager->get_setting( 'pikture_pro_theme_options[menu_type]' )->value();
	}
endif;