<?php
/**
 * Pikture Customizer.
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function pikture_pro_customize_register( $wp_customize ) {
	$options = pikture_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'pikture_pro_theme_options[header_title_color]', array(
		'default'           => $options['header_title_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'pikture_pro_theme_options[header_title_color]', array(
		'priority'			=> 5,
		'label'             => esc_html__( 'Header Title Color', 'pikture-pro' ),
		'section'           => 'colors',
	) ) );

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'pikture_pro_theme_options[header_tagline_color]', array(
		'default'           => $options['header_tagline_color'],
		'sanitize_callback' => 'sanitize_hex_color',
		'transport'			=> 'postMessage'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'pikture_pro_theme_options[header_tagline_color]', array(
		'priority'			=> 6,
		'label'             => esc_html__( 'Header Tagline Color', 'pikture-pro' ),
		'section'           => 'colors',
	) ) );

	// Site identity extra options.
	$wp_customize->add_setting( 'pikture_pro_theme_options[header_txt_logo_extra]', array(
		'default'           => $options['header_txt_logo_extra'],
		'sanitize_callback' => 'pikture_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[header_txt_logo_extra]', array(
		'priority'			=> 50,
		'type'				=> 'radio',
		'label'             => esc_html__( 'Site Identity Extra Options', 'pikture-pro' ),
		'section'           => 'title_tagline',
		'choices'				=> array( 
			'hide-all'     => esc_html__( 'Hide All', 'pikture-pro' ),
			'show-all'     => esc_html__( 'Show All', 'pikture-pro' ),
			'title-only'   => esc_html__( 'Title Only', 'pikture-pro' ),
			'tagline-only' => esc_html__( 'Tagline Only', 'pikture-pro' ),
			'logo-title'   => esc_html__( 'Logo + Title', 'pikture-pro' ),
			'logo-tagline' => esc_html__( 'Logo + Tagline', 'pikture-pro' ),
			)
	) );

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'pikture_pro_theme_options[colorscheme]', array(
		'default'           => $options['colorscheme'],
		'transport'         => 'postMessage',
		'sanitize_callback' => 'pikture_pro_sanitize_select',
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[colorscheme]', array(
		'type'    => 'radio',
		'label'    => esc_html__( 'Color Scheme', 'pikture-pro' ),
		'choices'  => array(
			'light'  => esc_html__( 'Light', 'pikture-pro' ),
			'dark'   => esc_html__( 'Dark', 'pikture-pro' ),
			'custom' => esc_html__( 'Custom', 'pikture-pro' ),
		),
		'section'  => 'colors',
	) );

	$wp_customize->add_setting( 'pikture_pro_theme_options[colorscheme_hue]', array(
		'default'           => $options['colorscheme_hue'],
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );


	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'pikture_pro_theme_options[colorscheme_hue]', array(
		'section'  => 'colors',
	) ) );

	// Accent color.
	$wp_customize->add_setting( 'pikture_pro_theme_options[accent_color]', array(
		'default'           => $options['accent_color'],
		'transport'         => 'postMessage',
		'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'pikture_pro_theme_options[accent_color]', array(
		'label'             => esc_html__( 'Accent color: ', 'pikture-pro' ),
		'description'             => esc_html__( 'This changes the secondary color which is used in buttons, icons and horizontal line below titles.', 'pikture-pro' ),
		'section'  => 'colors',
	) ) );

	// Add panel for common theme options
	$wp_customize->add_panel( 'pikture_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','pikture-pro' ),
	    'description'=> esc_html__( 'Pikture Theme Options.', 'pikture-pro' ),
	    'priority'   => 160,
	) );

	// Menu Options
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load breadcrumb option
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'pikture_pro_front_page_panel' , array(
	    'title'      => esc_html__( 'Front Page','pikture-pro' ),
	    'description'=> esc_html__( 'Front Page Theme Options.', 'pikture-pro' ),
	    'priority'   => 140,
	) );

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'pikture_pro_about_us_panel' , array(
	    'title'      => esc_html__( 'About Us Template','pikture-pro' ),
	    'description'=> esc_html__( 'About Us Template Options.', 'pikture-pro' ),
	    'priority'   => 150,
	) );

	// Load front page sections option
	require get_template_directory() . '/inc/customizer/sections/sections.php';

	/*
	 * Load partial refresh functions.
	 */
	require get_template_directory() . '/inc/customizer/partials.php';
}
add_action( 'customize_register', 'pikture_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function pikture_pro_customize_preview_js() {

	wp_enqueue_script( 'pikture-customizer', get_template_directory_uri() . '/assets/js/customizer' . pikture_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'pikture_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function pikture_pro_customize_control_js() {
	// Choose from select jquery.
	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . pikture_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	wp_enqueue_script( 'pikture-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . pikture_pro_min() . '.js', array(), '1.0.0', true );
	$pikture_pro_cusomizer_control_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'pikture-pro' ),
		'num_chng_msg' => esc_html__( 'Refresh the customizer page after saving to view effects.', 'pikture-pro' ),
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'pikture-customize-controls', 'pikture_pro_cusomizer_control_data', $pikture_pro_cusomizer_control_data );

	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . pikture_pro_min() . '.css' );

	wp_enqueue_style( 'customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . pikture_pro_min() . '.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'pikture_pro_customize_control_js' );

if ( !function_exists( 'pikture_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since Pikture Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function pikture_pro_reset_options() {
		$options = pikture_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'pikture_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'pikture_pro_reset_options' );
