<?php 

/**
 * Customizer Partial Functions
 *
 * @package Theme_Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */

if ( ! function_exists( 'pikture_pro_hero_content_text_refresh' ) ) :
	/**
	 * Render hero content text for the selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_hero_content_text_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['hero_content_text'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_custom_title_refresh' ) ) :
	/**
	 * Render about custom title selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_custom_title_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_custom_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_custom_sub_title_refresh' ) ) :
	/**
	 * Render about custom sub title selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_custom_sub_title_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_custom_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_custom_content_refresh' ) ) :
	/**
	 * Render about custom content selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_custom_content_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_custom_content'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_custom_btn_txt_refresh' ) ) :
	/**
	 * Render about custom btn text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_custom_btn_txt_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_custom_btn_text'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_panorama_title' ) ) :
	/**
	 * Render panorama title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_panorama_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['panorama_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_panorama_sub_title' ) ) :
	/**
	 * Render panorama sub title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_panorama_sub_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['panorama_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_panorama_btn_txt_refresh' ) ) :
	/**
	 * Render panorama button text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_panorama_btn_txt_refresh() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['panorama_btn_text'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_call_to_action_custom_title_refresh' ) ) :
	/**
	 * Render panorama custom title selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_call_to_action_custom_title_refresh() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['call_to_action_custom_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_call_to_action_custom_content_refresh' ) ) :
	/**
	 * Render panorama custom content selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_call_to_action_custom_content_refresh() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['call_to_action_custom_content'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_call_to_action_btn_txt_refresh' ) ) :
	/**
	 * Render panorama custom content btn txt selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_call_to_action_btn_txt_refresh() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['call_to_action_custom_btn_text'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_portrait_title' ) ) :
	/**
	 * Render portrait title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_portrait_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['portrait_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_portrait_sub_title' ) ) :
	/**
	 * Render portrait sub title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_portrait_sub_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['portrait_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_portrait_btn_txt_refresh' ) ) :
	/**
	 * Render portrait button text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_portrait_btn_txt_refresh() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['portrait_btn_text'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_client_title' ) ) :
	/**
	 * Render client title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_client_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['client_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_client_sub_title' ) ) :
	/**
	 * Render client sub title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_client_sub_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['client_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_landscape_title' ) ) :
	/**
	 * Render landscape title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_landscape_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['landscape_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_landscape_sub_title' ) ) :
	/**
	 * Render landscape sub title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_landscape_sub_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['landscape_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_landscape_btn_txt_refresh' ) ) :
	/**
	 * Render landscape button text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_landscape_btn_txt_refresh() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['landscape_btn_text'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_testimonial_title' ) ) :
	/**
	 * Render testimonial title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_testimonial_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['testimonial_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_testimonial_sub_title' ) ) :
	/**
	 * Render testimonial sub title text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_testimonial_sub_title() {
		$options = pikture_pro_get_theme_options();
		return esc_html( $options['testimonial_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_testimonial_content_refresh' ) ) :
	/**
	 * Render testimonial content text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_testimonial_content_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['testimonial_content'] );
	}
endif;


if ( ! function_exists( 'pikture_pro_copyright_text_refresh' ) ) :
	/**
	 * Render copyright text selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_copyright_text_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['copyright_text'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_portfolio_title_refresh' ) ) :
	/**
	 * Render about portfolio title selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_portfolio_title_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_portfolio_custom_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_portfolio_sub_title_refresh' ) ) :
	/**
	 * Render about portfolio sub title selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_portfolio_sub_title_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_portfolio_custom_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_portfolio_content_refresh' ) ) :
	/**
	 * Render about portfolio content selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_portfolio_content_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_portfolio_custom_content'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_portfolio_name_refresh' ) ) :
	/**
	 * Render about portfolio name selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_portfolio_name_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_portfolio_custom_name'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_portfolio_position_refresh' ) ) :
	/**
	 * Render about portfolio position selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_portfolio_position_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_portfolio_custom_position'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_contact_title_refresh' ) ) :
	/**
	 * Render about contact title selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_contact_title_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_contact_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_contact_sub_title_refresh' ) ) :
	/**
	 * Render about contact sub title selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_contact_sub_title_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_contact_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_about_temp_contact_content_refresh' ) ) :
	/**
	 * Render about contact content selective refresh partial.
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_about_temp_contact_content_refresh() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['about_temp_contact_content'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_panorama_your_latest_posts_sub_title' ) ) :
	/**
	 * Render homepage displayed latest post sub title
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_panorama_your_latest_posts_sub_title() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['your_latest_posts_sub_title'] );
	}
endif;

if ( ! function_exists( 'pikture_pro_panorama_your_latest_posts_title' ) ) :
	/**
	 * Render homepage displayed latest post title
	 *
	 * @since 1.0
	 *
	 * @return string
	 */
	function pikture_pro_panorama_your_latest_posts_title() {
		$options = pikture_pro_get_theme_options();
		return wp_kses_post( $options['your_latest_posts_title'] );
	}
endif;