<?php
/**
 * Client options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add client section
$wp_customize->add_section( 'pikture_pro_client_section', array(
	'title'             => esc_html__( 'Client','pikture-pro' ),
	'description'       => esc_html__( 'Client options works only on Front page. Images with size of 213px by 121px( or of same ratio ) would look the best in this section.', 'pikture-pro' ),
	'panel'             => 'pikture_pro_front_page_panel',
) );

// Client content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_client_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_client_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_client_section]', array(
	'label'             => esc_html__( 'Client Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_client_section',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// Client title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['client_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[client_title]', array(
	'label'             => esc_html__( 'Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_client_section',
	'active_callback' 	=> 'pikture_pro_is_client_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[client_title]', array(
		'selector'            => '#client .entry-title',
		'render_callback'     => 'pikture_pro_client_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Client sub title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
	'default'          	=> $options['client_sub_title'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[client_sub_title]', array(
	'label'             => esc_html__( 'Sub Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_client_section',
	'active_callback' 	=> 'pikture_pro_is_client_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[client_sub_title]', array(
		'selector'            => '#client .sub-title',
		'render_callback'     => 'pikture_pro_client_sub_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Client custom image control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_bg]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_image',
	'default'          	=> $options['client_bg'],
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[client_bg]', array(
	'label'             => esc_html__( 'Background Image:', 'pikture-pro' ),
	'section'         => 'pikture_pro_client_section',
	'active_callback' => 'pikture_pro_is_client_enable',
) ) );

/**
 * Client slider settings.
 */
// Client slider pager enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_pager_enable]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['client_pager_enable'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[client_pager_enable]', array(
	'label'           => esc_html__( 'Pager/Dots:', 'pikture-pro' ),
	'section'         => 'pikture_pro_client_section',
	'active_callback' => 'pikture_pro_is_client_enable',
	'on_off_label'    => pikture_pro_switch_options(),
) ) );

// Client slider arrows enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_arrows_enable]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['client_arrows_enable'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[client_arrows_enable]', array(
	'label'           => esc_html__( 'Arrows:', 'pikture-pro' ),
	'section'         => 'pikture_pro_client_section',
	'active_callback' => 'pikture_pro_is_client_enable',
	'on_off_label'    => pikture_pro_switch_options(),
) ) );

// Client slider autoplay control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_autoplay_enable]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['client_autoplay_enable'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[client_autoplay_enable]', array(
	'label'           => esc_html__( 'Autoplay:', 'pikture-pro' ),
	'section'         => 'pikture_pro_client_section',
	'active_callback' => 'pikture_pro_is_client_enable',
	'on_off_label'    => pikture_pro_switch_options(),
) ) );

// Client slider infinite control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_infinite_enable]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['client_infinite_enable'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[client_infinite_enable]', array(
	'label'           => esc_html__( 'Infinite:', 'pikture-pro' ),
	'section'         => 'pikture_pro_client_section',
	'active_callback' => 'pikture_pro_is_client_enable',
	'on_off_label'    => pikture_pro_switch_options(),
) ) );

// Client slider to show control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_num_to_show]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_number_range',
	'default'          	=> $options['client_num_to_show'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[client_num_to_show]', array(
	'label'             => esc_html__( 'Clients to show: ', 'pikture-pro' ),
	'label'             => esc_html__( 'Number of clients to be shown on the  first slide.', 'pikture-pro' ),
	'description'             => esc_html__( 'This changes the number of slider items which is shown on the first load.', 'pikture-pro' ),
	'section'           => 'pikture_pro_client_section',
	'type' 				=> 'number',
	'active_callback'	=> 'pikture_pro_is_client_enable',
	'input_attrs'		=> array( 'min' => 1, 'max' => 5 ),
) );

// Client content type separator control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_content_type_hr_line]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_html',
) );

$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[client_content_type_hr_line]', array(
	'active_callback'	=> 'pikture_pro_is_client_enable',
	'section'           => 'pikture_pro_client_section',
) ) );


// Client content type control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['client_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[client_content_type]', array(
	'label'             => esc_html__( 'Content Type:', 'pikture-pro' ),
	'section'           => 'pikture_pro_client_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_client_enable',
	'choices'			=> pikture_pro_client_content_type(),
) );

// Client count control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_num]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_number_range',
	'default'          	=> $options['client_num'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[client_num]', array(
	'label'             => esc_html__( 'Number of clients ( Max: 10 ): ', 'pikture-pro' ),
	'section'           => 'pikture_pro_client_section',
	'type' 				=> 'number',
	'active_callback'	=> 'pikture_pro_is_client_content_demo_disable',
	'input_attrs'		=> array( 'min' => 1, 'max' => 10 ),
) );

/**
 * Content type: Category.
 */
// Portrait client control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[client_category]', array(
	'sanitize_callback' => 'absint',
) );

$wp_customize->add_control( new Pikture_Pro_Dropdown_Category_Control( $wp_customize, 'pikture_pro_theme_options[client_category]', array(
	'label'           => esc_html__( 'Category:', 'pikture-pro' ),
	'description'     => esc_html__( "Image and url will be used from the selected category's recent posts' featured image and permalink respectively.", 'pikture-pro' ),
	'section'         => 'pikture_pro_client_section',
	'active_callback' => 'pikture_pro_is_client_content_category_enable',
	'multiple'        => false,
) ) );

for ( $i=1; $i <= absint( $options['client_num'] ); $i++ ) { 
	/**
	 * Content type: Custom.
	 */
	// Client custom image control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[client_custom_image_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_image',
		'default'          	=> $options['client_custom_image'],
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[client_custom_image_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Image %d:', 'pikture-pro' ), $i ),
		'section'         => 'pikture_pro_client_section',
		'active_callback' => 'pikture_pro_is_client_content_custom_enable',
	) ) );

	// Client custom link control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[client_custom_link_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
		'default'          	=> $options['client_custom_link'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[client_custom_link_'.$i.']', array(
		'label'             => sprintf( esc_html__( 'Link %d:', 'pikture-pro' ), $i ),
		'section'           => 'pikture_pro_client_section',
		'active_callback' 	=> 'pikture_pro_is_client_content_custom_enable',
	) );

	// Client separator control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[client_hr_line_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
	) );

	$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[client_hr_line_'.$i.']', array(
		'active_callback'	=> 'pikture_pro_is_client_content_custom_enable',
		'section'           => 'pikture_pro_client_section',
	) ) );

	/**
	 * Content type: Page.
	 */
	// Client content type page control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[client_page_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[client_page_id_'.$i.']', array(
		'label'             => esc_html__( 'Page ', 'pikture-pro' ) . $i,
		'description'     => esc_html__( "Image and url will be used from the selected post's featured image and permalink respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_client_content_page_enable',
		'section'           => 'pikture_pro_client_section',
		'type'				=> 'dropdown-pages',
	) );

	/**
	 * Content type: Post.
	 */
	// Client content type post control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[client_post_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[client_post_id_'.$i.']', array(
		'label'             => esc_html__( 'Post ', 'pikture-pro' ) . $i,
		'description'     => esc_html__( "Image and url will be used from the selected post's featured image and permalink respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_client_content_post_enable',
		'section'           => 'pikture_pro_client_section',
		'choices'         => pikture_pro_posts_choices(),
	) ) );
}