<?php
/**
 * Featured options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add featured section
$wp_customize->add_section( 'pikture_pro_featured_section', array(
	'title'             => esc_html__( 'Featured','pikture-pro' ),
	'description'       => esc_html__( 'Featured options works only on Front page. Images with ratio of 2:3 ( for e.g: 640px by 960px ) would look the best in this section. The Heart This plugin ( i.e. like functionality ) will work only on Content Type: Page and Post.', 'pikture-pro' ),
	'panel'             => 'pikture_pro_front_page_panel',
) );

// Featured content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_featured_section]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_featured_section'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_featured_section]', array(
	'label'             => esc_html__( 'Featured Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_featured_section',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

// Featured content type control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[featured_content_type]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_select',
	'default'          	=> $options['featured_content_type'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[featured_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'pikture-pro' ),
	'section'           => 'pikture_pro_featured_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'pikture_pro_is_featured_content_enable',
	'choices'			=> pikture_pro_featured_content_type(),
) );

for ( $i=1; $i < 4; $i++ ) { 
	/**
	 * Content type: Custom.
	 */
	// Featured custom title control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[featured_custom_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'          	=> $options['featured_custom_title'],
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[featured_custom_title_'.$i.']', array(
		'label'             => esc_html__( 'Title ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_featured_section_content_custom_enable',
		'section'           => 'pikture_pro_featured_section',
	) );

	// Featured custom image control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[featured_custom_image_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_image',
		'default'          	=> $options['featured_custom_image'],
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[featured_custom_image_'.$i.']', array(
		'label'             => esc_html__( 'Image ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_featured_section_content_custom_enable',
		'section'           => 'pikture_pro_featured_section',
	) ) );

	// Featured custom link control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[featured_custom_link_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
		'default'          	=> '#',
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[featured_custom_link_'.$i.']', array(
		'label'             => esc_html__( 'Link ', 'pikture-pro' ) . $i,
		'active_callback' 	=> 'pikture_pro_is_featured_section_content_custom_enable',
		'section'           => 'pikture_pro_featured_section',
		'type'				=> 'url'
	) );

	// Featured custom separator control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[featured_custom_hr_line_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_html',
	) );

	$wp_customize->add_control( new Pikture_Pro_Customize_Horizontal_Line( $wp_customize, 'pikture_pro_theme_options[featured_custom_hr_line_'.$i.']', array(
		'active_callback' 	=> 'pikture_pro_is_featured_section_content_custom_enable',
		'section'           => 'pikture_pro_featured_section',
	) ) );

	/**
	 * Content type: Page.
	 */
	// Featured content type page control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[featured_page_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( 'pikture_pro_theme_options[featured_page_id_'.$i.']', array(
		'label'             => esc_html__( 'Page ', 'pikture-pro' ) . $i,
		'description'             => esc_html__( "Image and url will be used from the selected page's featured image and permalink respectively.", 'pikture-pro' ),
		'active_callback' 	=> 'pikture_pro_is_featured_section_content_page_enable',
		'section'           => 'pikture_pro_featured_section',
		'type'				=> 'dropdown-pages',
	) );

	/**
	 * Content type: Post.
	 */
	// Featured content type post control and setting
	$wp_customize->add_setting( 'pikture_pro_theme_options[featured_post_id_'.$i.']', array(
		'sanitize_callback' => 'pikture_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Pikture_Pro_Dropdown_Chooser( $wp_customize, 'pikture_pro_theme_options[featured_post_id_'.$i.']', array(
		'label'           => esc_html__( 'Post ', 'pikture-pro' ) . $i,
		'description'     => esc_html__( "Image and url will be used from the selected post's featured image and permalink respectively.", 'pikture-pro' ),
		'active_callback' => 'pikture_pro_is_featured_section_content_post_enable',
		'section'         => 'pikture_pro_featured_section',
		'choices'         => pikture_pro_posts_choices(),
	) ) );
}