<?php
/**
 * About template contact options
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

// Add about template contact section
$wp_customize->add_section( 'pikture_pro_about_temp_contact', array(
	'title'             => esc_html__( 'Contact','pikture-pro' ),
	'description'       => esc_html__( 'Contact options( Works only on page with "About Us" template assigned. ). Images with ratio of 2:3 would look the best in this section.', 'pikture-pro' ),
	'panel'             => 'pikture_pro_about_us_panel',
) );

// Contact content enable control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_about_temp_contact]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_switch_control',
	'default'          	=> $options['enable_about_temp_contact'],
) );

$wp_customize->add_control( new Pikture_Pro_Switch_Control( $wp_customize, 'pikture_pro_theme_options[enable_about_temp_contact]', array(
	'label'             => esc_html__( 'Contact Section:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_contact',
	'on_off_label' 		=> pikture_pro_switch_options(),
) ) );

/**
 * Content type: Custom.
 */
// Contact custom title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_contact_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_temp_contact_title'],
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_contact_title]', array(
	'label'             => esc_html__( 'Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_contact',
	'active_callback' 	=> 'pikture_pro_is_about_temp_contact_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_contact_title]', array(
		'selector'            => '#get-in-touch h2.entry-title',
		'render_callback'     => 'pikture_pro_about_temp_contact_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Contact custom sub title control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_contact_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['about_temp_contact_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_contact_sub_title]', array(
	'label'             => esc_html__( 'Sub Title:', 'pikture-pro' ),
	'section'           => 'pikture_pro_about_temp_contact',
	'active_callback' 	=> 'pikture_pro_is_about_temp_contact_enable',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_contact_sub_title]', array(
		'selector'            => '#get-in-touch span.sub-title',
		'render_callback'     => 'pikture_pro_about_temp_contact_sub_title_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Contact custom content control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_contact_content]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_html',
	'transport'			=> 'postMessage',
	'default'          	=> $options['about_temp_contact_content'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_contact_content]', array(
	'label'           => esc_html__( 'Content:', 'pikture-pro' ),
	'description'     => esc_html__( 'HTML Allowed', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_temp_contact',
	'active_callback' => 'pikture_pro_is_about_temp_contact_enable',
	'type'            => 'textarea',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[about_temp_contact_content]', array(
		'selector'            => '#get-in-touch .entry-content',
		'render_callback'     => 'pikture_pro_about_temp_contact_content_refresh',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Contact custom content control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_contact_shortcode]', array(
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[about_temp_contact_shortcode]', array(
	'label'           => esc_html__( 'Form Shortcode:', 'pikture-pro' ),
	'description'           => sprintf( esc_html__( 'For form shortcode, you can use plugins like: %1$sContact Form 7 %2$s', 'pikture-pro' ), '<a target="__blank" href="https://wordpress.org/plugins/contact-form-7/">', '</a>' ),
	'section'         => 'pikture_pro_about_temp_contact',
	'active_callback' => 'pikture_pro_is_about_temp_contact_enable',
	'type'            => 'textarea',
) );

// Contact custom image control and setting
$wp_customize->add_setting( 'pikture_pro_theme_options[about_temp_contact_image]', array(
	'sanitize_callback' => 'pikture_pro_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'pikture_pro_theme_options[about_temp_contact_image]', array(
	'label'           => esc_html__( 'Image:', 'pikture-pro' ),
	'section'         => 'pikture_pro_about_temp_contact',
	'active_callback' => 'pikture_pro_is_about_temp_contact_enable',
) ) );