<?php
/**
* Homepage (Static ) options
*
* @package Theme Palace
* @subpackage Pikture Pro
* @since Pikture Pro 1.0.0
*/

// Homepage (Static ) setting and control.
$wp_customize->add_setting( 'pikture_pro_theme_options[enable_frontpage_content]', array(
	'sanitize_callback'   => 'pikture_pro_sanitize_checkbox',
	'default'             => $options['enable_frontpage_content'],
) );

$wp_customize->add_control( 'pikture_pro_theme_options[enable_frontpage_content]', array(
	'label'       	=> esc_html__( 'Enable Content', 'pikture-pro' ),
	'description' 	=> esc_html__( 'Check to display Homepage\'s content.', 'pikture-pro' ),
	'section'     	=> 'static_front_page',
	'active_callback'   => 'pikture_pro_if_homepage_displays_static_page',
	'type'        	=> 'checkbox',
) );

// Your latest posts title setting and control.
$wp_customize->add_setting( 'pikture_pro_theme_options[your_latest_posts_title]', array(
	'default'           => $options['your_latest_posts_title'],
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[your_latest_posts_title]', array(
	'label'             => esc_html__( 'Your Latest Posts Title', 'pikture-pro' ),
	'description'       => esc_html__( 'This option only works if Static Front Page is set to "Your latest posts."', 'pikture-pro' ),
	'section'           => 'static_front_page',
	'type'				=> 'text',
	'active_callback'   => 'pikture_pro_if_homepage_displays_latest_posts'
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[your_latest_posts_title]', array(
		'selector'            => '.home.blog .page-header .page-title',
		'render_callback'     => 'pikture_pro_panorama_your_latest_posts_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Your latest posts sub title setting and control.
$wp_customize->add_setting( 'pikture_pro_theme_options[your_latest_posts_sub_title]', array(
	'default'           => $options['your_latest_posts_sub_title'],
	'transport'			=> 'postMessage',
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'pikture_pro_theme_options[your_latest_posts_sub_title]', array(
	'label'             => esc_html__( 'Blog Page Sub Title', 'pikture-pro' ),
	'section'           => 'static_front_page',
	'type'				=> 'text',
	'active_callback'   => 'pikture_pro_if_homepage_displays_latest_posts'
) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'pikture_pro_theme_options[your_latest_posts_sub_title]', array(
		'selector'            => '.home.blog .page-header .sub-title',
		'render_callback'     => 'pikture_pro_panorama_your_latest_posts_sub_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Latest posts sidebar position setting and control.
$wp_customize->add_setting( 'pikture_pro_theme_options[latest_post_sidebar_position]', array(
	'sanitize_callback'   => 'pikture_pro_sanitize_select',
	'default'             => $options['latest_post_sidebar_position'],
) );

$wp_customize->add_control( new Pikture_Pro_Custom_Radio_Image_Control( $wp_customize, 'pikture_pro_theme_options[latest_post_sidebar_position]', array(
	'label'               => esc_html__( "Latest posts' sidebar position:", 'pikture-pro' ),
	'section'             => 'static_front_page',
	'choices'			  => pikture_pro_sidebar_position(),
	'active_callback'   => 'pikture_pro_if_homepage_displays_latest_posts'
) ) );