<?php
/**
 * Metabox file.
 *
 * This is the template that shows the metaboxes.
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
 */

/**
 * Adds a box to the main column on the Post and Page edit screens.
 */
function pikture_pro_sidebar_layout_meta_box(){

    $screens = array( 'post', 'page' );

    add_meta_box(
        'pikture_pro_sidebar_layout',
        __( 'Sidebar Layout', 'pikture-pro' ),
        'pikture_pro_sidebar_layout_meta_box_callback',
        $screens,
        'side',
        'high'
    );
}

add_action( 'add_meta_boxes', 'pikture_pro_sidebar_layout_meta_box' );

/**
 * Prints the box content.
 * 
 * @param WP_Post $post The object for the current post/page.
 */
function pikture_pro_sidebar_layout_meta_box_callback( $post ){

    // Add a nonce field so we can check for it later.
    wp_nonce_field( 'pikture_pro_sidebar_layout_save_meta_box', 'pikture_pro_sidebar_layout_meta_box_nonce' );

    /*
     * Use get_post_meta() to retrieve an existing value
     * from the database and use the value for the form.
     */
    $pikture_pro_sidebar_layout = get_post_meta( $post->ID, 'pikture_pro_sidebar_layout', true );

    if( ! $pikture_pro_sidebar_layout ) {
        $pikture_pro_sidebar_layout = '';
    }

    $sidebar_positions = pikture_pro_sidebar_position();
    foreach ( $sidebar_positions as $value => $url ) :
        echo '<label>';
        echo '<input type="radio" name="pikture_pro_sidebar_layout" value="' . esc_attr( $value ) . '" ' . checked( $pikture_pro_sidebar_layout, $value, false ) . ' />';
        echo '<img src="' . esc_url( $url ) . '"/>';
        echo '</label>';
    endforeach;
}

/**
 * When the post is saved, saves our custom data.
 *
 * @param int $post_id The ID of the post being saved.
 */
function pikture_pro_sidebar_layout_save_meta_box( $post_id ){

    /*
     * We need to verify this came from our screen and with proper authorization,
     * because the save_post action can be triggered at other times.
     */

    // Check if our nonce is set.
    if ( ! isset( $_POST['pikture_pro_sidebar_layout_meta_box_nonce'] ) ) {
        return;
    }

    // Verify that the nonce is valid.
    if ( ! wp_verify_nonce( sanitize_key( $_POST['pikture_pro_sidebar_layout_meta_box_nonce'] ), 'pikture_pro_sidebar_layout_save_meta_box' ) ) {
        return;
    }

    // If this is an autosave, our form has not been submitted, so we don't want to do anything.
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }

    // Check the user's permissions.
    if ( ! current_user_can( 'edit_post', $post_id ) ) {
        return;
    }

    /* OK, it's safe for us to save the data now. */
    
    // Make sure that it is set.
    if ( isset( $_POST['pikture_pro_sidebar_layout'] ) ) {
        // Sanitize user input.
        $pikture_pro_data = sanitize_text_field( wp_unslash( $_POST['pikture_pro_sidebar_layout'] ) );
        // Update the meta field in the database.
        update_post_meta( $post_id, 'pikture_pro_sidebar_layout', $pikture_pro_data );
    }
        
}

add_action( 'save_post', 'pikture_pro_sidebar_layout_save_meta_box' );