<?php
/**
 * About section
 *
 * This is the template for the call to action section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_counter_about_section' ) ) :
  /**
   * Add call to action section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_counter_about_section() {
    // Check if call to action is enabled on frontpage
    $enable_about_section = apply_filters( 'pikture_pro_section_status', true, 'enable_about_section' );
    
    if ( true !== $enable_about_section ) {
        return false;
    }

    // Get call to action section details
    $section_details = array();
    $section_details = apply_filters( 'pikture_pro_filter_counter_about_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render call to action section now.
    pikture_pro_render_counter_about_section( $section_details );
  }
endif;
add_action( 'pikture_pro_content_start_action', 'pikture_pro_add_counter_about_section', 20 );


if ( ! function_exists( 'pikture_pro_get_counter_about_section_details' ) ) :
  /**
   * call to action section details.
   *
   * @since Pikture Pro 1.0.0
   * @param array $input call to action section details.
   */
  function pikture_pro_get_counter_about_section_details( $input ) {
    $options = pikture_pro_get_theme_options();

    // Content type.
    $about_content_type  = $options['about_content_type'];
    $content = array();
    switch ( $about_content_type ) {
        case 'demo':
            $demo['title']     = esc_html__( 'Helen Tran', 'pikture-pro' );
            $demo['sub_title'] = esc_html__( 'About Me', 'pikture-pro' );
            $demo['content']   = sprintf( esc_html__( '%1$sPraesent sit amet porta nunc. Aenean nulla ipsum, tempus porta blandit eu, sagittis vel ex. Morbi imperdiet nibh id ipsum finibus convallis. Nulla feugiat vestibulum lacus ut iaculis. Pellentesque consequat nulla vitae ante porttitor elementum.%2$s
            %1$sIn porta diam vel leo ornare maximus. Sed aliquam nunc ut lobortis consequat. Donec posuere, lectus in tristique lacinia, purus enim feugiat urna, sit amet iaculis lectus purus vitae mi. Mauris in dictum erat fusce malesuada lacinia ante.%2$s', 'pikture-pro' ), '<p>', '</p>' );
            $demo['img']       = get_template_directory_uri() . '/assets/uploads/about-01.jpg';
            $demo['btn_txt']   = esc_html__( 'View Details', 'pikture-pro' );
            $demo['btn_url']   = '#';

            // Push to the main array.
            array_push( $content, $demo );
        break;

        case 'custom':
            $custom['title']     = $options['about_custom_title'];
            $custom['sub_title'] = $options['about_custom_sub_title'];
            $custom['content']   = $options['about_custom_content'];
            $custom['img']       = ( isset( $options['about_custom_image'] ) ) ? $options['about_custom_image'] : '';
            $custom['btn_txt']   = $options['about_custom_btn_text'];
            $custom['btn_url']   = $options['about_custom_btn_link'];

            array_push( $content, $custom );
            $content = array_filter( $content );
        break;

        case 'page':
            if ( isset( $options['about_page_id'] ) ) {
                $id = $options['about_page_id'];
            }
        break;

        case 'post':
            if ( isset( $options['about_post_id'] ) ) {
                $id = $options['about_post_id'];
            }
        break;

        default:
        break;
    }
    if ( 'post' === $about_content_type || 'page' === $about_content_type ) {
        if( ! empty ( $id ) ) {
            // Prepare arguments.
            $args = array(
                'post_type'           => $about_content_type,
                'p'                   => $id,
                'ignore_sticky_posts' => true
            );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['sub_title'] = $options['about_custom_sub_title'];
                    // Check if it is post or page. If post get excerpt. If page, strip the content.
                    $post_type = get_post_type();
                    $raw_content = pikture_pro_trim_content( 100 );
                    $page_post['content'] = '<p>' . $raw_content . '</p>';
                    $page_post['img']       = get_the_post_thumbnail_url();
                    $page_post['btn_txt']   = $options['about_custom_btn_text'];
                    $page_post['btn_url']   = get_permalink();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
                wp_reset_postdata();
            endif;
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// About section content details.
add_filter( 'pikture_pro_filter_counter_about_section_details', 'pikture_pro_get_counter_about_section_details' );


if ( ! function_exists( 'pikture_pro_render_counter_about_section' ) ) :
  /**
   * Start call to action section
   *
   * @return string About content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_counter_about_section( $content_details = array() ) {
        $about_img      = $content_details[0]['img'];
        $options        = pikture_pro_get_theme_options();
        $enable_counter = $options['enable_counter_section'];

        $col_class = '';
        if ( $enable_counter && ! empty( $about_img ) ) {
            $col_class = 'col-3';
        } elseif ( ! $enable_counter && empty( $about_img ) ) {
            $col_class = 'col-1';
        } else {
            $col_class = 'col-2';
        }
        
        $div_class      = ( $enable_counter ) ? '' : 'no-counter';
        ?>
        <div id="about" class="<?php echo esc_attr( $col_class ); ?> page-section relative">
            <?php if ( $enable_counter ) : ?>
                <div class="counter hentry">
                    <?php for ( $i=1; $i < 4; $i++ ) {  ?>
                        <div class="statwrap">
                            <?php 
                            $icon = ( isset( $options['counter_icon_' .$i ] ) ) ? $options['counter_icon_' .$i ] : $options['counter_icon' ];
                            if ( $icon ) {
                                echo pikture_pro_get_svg( array( 'icon' => $icon ) );
                            }

                            $counter = ( isset( $options['counter_count_' .$i ] ) ) ? $options['counter_count_' .$i ] : $options['counter_count' ] ;
                            if ( $counter ) :
                            ?>
                                <span class="count"><?php echo absint( $counter ); ?></span>
                            <?php endif;
                            $counter_text = ( isset( $options['counter_text_' .$i ] ) ) ? $options['counter_text_' .$i ] : $options['counter_text'];
                            if ( $counter_text ) : ?>
                                <small><?php  echo esc_html( $counter_text ); ?></small>
                            <?php endif; ?>
                        </div><!-- .statwrap -->
                    <?php } ?>
                </div><!-- .counter/hentry -->
            <?php endif;

            if ( empty( $content_details ) ) {
                return;
            }

            foreach ( $content_details as $content ): ?>
                <div class="about-text <?php echo esc_attr( $div_class ); ?>  hentry">
                    <div class="entry-container">
                        <header class="entry-header">
                            <span class="sub-title"><?php echo esc_html( $content['sub_title'] ); ?></span>
                            <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            <div class="seperator"></div>
                        </header><!-- .entry-header -->

                        <div class="entry-content">
                            <?php echo wp_kses_post( $content['content'] ); ?>
                        </div><!-- .entry-content -->
                        <a href="<?php echo esc_url( $content['btn_url'] ); ?>" class="btn btn-green"><?php echo esc_html( $content['btn_txt'] ); ?></a>
                    </div><!-- .entry-container -->
                </div><!-- .about-text -->

                <?php if ( ! empty( $content['img'] ) ) : ?>
                    <div class="featured hentry">
                       <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['img'] ); ?>');">
                        </div><!-- .featured-image -->
                    </div><!-- .hentry -->
                <?php endif; ?>
            <?php endforeach;?>
        </div><!-- #about -->
<?php
    }
endif;