<?php
/**
 * portrait section
 *
 * This is the template for the portrait section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_portrait_section' ) ) :
  /**
   * Add portrait section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_portrait_section() {
    // Check if portrait is enabled on frontpage
    $enable_portrait_section = apply_filters( 'pikture_pro_section_status', true, 'enable_portrait_section' );
    
    if ( true !== $enable_portrait_section ) {
        return false;
    }

    // Get portrait section details
    $section_details = array();
    $section_details = apply_filters( 'pikture_pro_filter_portrait_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render portrait section now.
    pikture_pro_render_portrait_section( $section_details );
  }
endif;
add_action( 'pikture_pro_content_start_action', 'pikture_pro_add_portrait_section', 20 );


if ( ! function_exists( 'pikture_pro_get_portrait_section_details' ) ) :
  /**
   * portrait section details.
   *
   * @since Pikture Pro 1.0.0
   * @param array $input portrait section details.
   */
  function pikture_pro_get_portrait_section_details( $input ) {
    $options = pikture_pro_get_theme_options();

    // Content type.
    $portrait_content_type  = $options['portrait_content_type'];
    $content = array();
    switch ( $portrait_content_type ) {
        case 'demo':
            for ( $i = 1; $i < 5; $i++ ) { 
                $demo['img']       = get_template_directory_uri() . '/assets/uploads/portrait-0'.$i.'.jpg';
                $demo['btn_txt']  = esc_html__( 'View More', 'pikture-pro' );
                $demo['btn_link'] = '#';

                // Push to the main array.
                array_push( $content, $demo );
            }
        break;

        case 'gallery':
            $portrait_gallery = ( isset( $options['portrait_gallery'] ) ) ? $options['portrait_gallery'] : '';
            $img_id_arr = explode( ",", $portrait_gallery );
            foreach ( $img_id_arr as $img_id ) {
                $gallery['img']      = wp_get_attachment_url( absint( $img_id ) );
                $gallery['btn_txt']  = $options['portrait_btn_text'];
                $gallery['btn_link'] = $options['portrait_custom_btn_link'];

                // Push to the main array.
                array_push( $content, $gallery );
            }
        break;

        case 'category':
            if ( isset( $options['portrait_category'] ) ) {
                $id = $options['portrait_category'];
            }
        break;

        case 'page':
            $id = array();
            for ( $i=1; $i <= $options['portrait_num_of_img']; $i++ ) {
                if ( isset( $options['portrait_page_id_' . $i ] ) ) {
                    array_push( $id, $options['portrait_page_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id = array_filter( $id );
        break;

        case 'post':
            $id = array();
            for ( $i=1; $i <= $options['portrait_num_of_img']; $i++ ) {
                if ( isset( $options['portrait_post_id_' . $i ] ) ) {
                    array_push( $id, $options['portrait_post_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id = array_filter( $id );
        break;

        default:
        break;
    }
    if ( 'category' === $portrait_content_type || 'post' === $portrait_content_type || 'page' === $portrait_content_type ) {
        if( ! empty ( $id ) ) {
            // Prepare arguments.
            $args = array(
                'ignore_sticky_posts' => true,
                'posts_per_page'      => $options['portrait_num_of_img'],
                'orderby'             => 'post__in'
            );

            $conditional_args = array();
            if ( 'category' === $portrait_content_type ) {
                $args['cat'] = absint( $id );
            } else {
                $args['post_type'] = $portrait_content_type;
                $args['post__in']  = $id;
            }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['down_img'] = get_the_post_thumbnail_url();
                    $page_post['img']      = get_the_post_thumbnail_url( get_the_ID(), 'large' );
                    $page_post['url']      = get_permalink();

                    // Add counter data from Heart This plugin.
                    if ( function_exists( 'heart_this_get_hearts' ) ) {
                        $page_post['counter'] = heart_this_get_hearts( get_the_ID() );
                    }

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
                wp_reset_postdata();
            endif;
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// portrait section content details.
add_filter( 'pikture_pro_filter_portrait_section_details', 'pikture_pro_get_portrait_section_details' );


if ( ! function_exists( 'pikture_pro_render_portrait_section' ) ) :
  /**
   * Start portrait section
   *
   * @return string portrait content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_portrait_section( $content_details = array() ) {
        $options        = pikture_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="portrait" class="page-section vertical relative">
            <header class="entry-header align-center">
                <span class="sub-title"><?php echo esc_html( $options['portrait_sub_title'] ); ?></span>
                <h2 class="entry-title"><?php echo esc_html( $options['portrait_title'] ); ?></h2>
                <div class="seperator"></div>
            </header><!-- .entry-header -->

            <div class="entry-content">
                <div class="gallery-popup">
                    <?php foreach ( $content_details as $content ): 
                            $img_url = ( ! empty( $content['img'] ) ) ? $content['img'] : get_template_directory_uri() . '/assets/uploads/featured-placeholder.jpg';

                            $down_img = ( isset( $content['down_img'] ) ) ? $content['down_img'] : $img_url;
                            ?>
                        <div class="grid-item">
                            <figure>
                                <?php if ( isset( $content['url'] ) ) { ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>">
                                <?php } ?>
                                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $img_url ); ?>')"></div>
                                <?php if ( isset( $content['url'] ) ) { ?>
                                    </a>
                                <?php } ?>

                                <div class="hover-item">
                                    <?php if ( isset( $content['counter'] ) ) : ?>
                                        <div class="heart-icon">
                                            <?php echo wp_kses_post( $content['counter'] ); ?>
                                        </div>
                                    <?php endif; ?>

                                    <?php if ( $options['download_icon'] ): ?>
                                        <a download href="<?php echo esc_url( $down_img ); ?>" class="download">
                                            <?php echo pikture_pro_get_svg( array( 'icon' => 'download' ) ); ?>
                                        </a>
                                    <?php endif; ?>
                                </div><!-- .hover-item -->

                                <?php if ( isset( $content['url'] ) ) { ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="add-to-collection">
                                        <?php echo pikture_pro_get_svg( array( 'icon' => 'collection' ) ); ?>
                                        <span class="collection"><?php esc_html_e( 'Show Detail', 'pikture-pro' ); ?></span>
                                    </a>
                                <?php } ?>

                                <?php if ( isset( $content['counter'] ) ) : ?>
                                    <span class="likes">
                                        <?php echo pikture_pro_get_svg( array( 'icon' => 'like' ) ); ?>
                                        <?php echo wp_kses_post( $content['counter'] ); ?>
                                    </span>
                                <?php endif; ?>
                            </figure>

                            <div class="hover-item">
                                <?php if ( isset( $content['counter'] ) ) : ?>
                                        <div class="heart-icon">
                                        <?php echo wp_kses_post( $content['counter'] ); ?>
                                    </div>
                                <?php endif; ?>

                                <?php if ( isset( $content['counter'] ) ) : ?>
                                    <span class="likes">
                                        <?php echo pikture_pro_get_svg( array( 'icon' => 'like' ) ); ?>
                                        <?php echo wp_kses_post( $content['counter'] ); ?>
                                    </span>
                                <?php endif; ?>

                                <?php if ( isset( $content['url'] ) ) { ?>
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="add-to-collection">
                                        <?php echo pikture_pro_get_svg( array( 'icon' => 'collection' ) ); ?>
                                        <span class="collection"><?php esc_html_e( 'Show Detail', 'pikture-pro' ); ?></span>
                                    </a>
                                <?php } ?>

                                <?php if ( $options['download_icon'] ): ?>
                                    <a download href="<?php echo esc_url( $down_img ); ?>" class="download">
                                        <?php echo pikture_pro_get_svg( array( 'icon' => 'download' ) ); ?>
                                    </a>
                                <?php endif; ?>
                            </div><!-- .hover-item -->
                        </div><!-- .grid-item -->
                    <?php endforeach;?>
                </div><!-- .gallery-popup -->
            </div><!-- .entry-content -->

            <?php 
            $portrait_content_type  = $options['portrait_content_type'];
            if ( 'category' === $portrait_content_type ) {
                $btn_txt = $options['portrait_btn_text'];
                $btn_link = get_category_link( $options['portrait_category'] );
            } else {
                $btn_txt = $options['portrait_btn_text'];
                $btn_link = $options['portrait_custom_btn_link'];
            }

            if ( ! empty( $btn_txt ) ) : ?>
                <div class="align-center">
                    <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-green"><?php echo esc_html( $btn_txt ); ?></a>
                </div><!-- .align-center-->
            <?php endif; ?>
        </div><!-- #portrait -->
<?php
    }
endif;