<?php
/**
 * About section
 *
 * This is the template for the call to action section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_about_temp_portfolio_section' ) ) :
  /**
   * Add call to action section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_about_temp_portfolio_section() {
    // Check if about template counter is enabled.
    $options = pikture_pro_get_theme_options();
    
    if ( ! $options['enable_about_temp_portfolio_section'] ) {
        return false;
    }

    // Get call to action section details
    $section_details = array();
    $section_details = apply_filters( 'pikture_pro_filter_about_temp_portfolio_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render call to action section now.
    pikture_pro_render_about_temp_portfolio_section( $section_details );
  }
endif;
add_action( 'pikture_pro_about_us_template', 'pikture_pro_add_about_temp_portfolio_section', 30 );


if ( ! function_exists( 'pikture_pro_get_about_temp_portfolio_section_details' ) ) :
  /**
   * call to action section details.
   *
   * @since Pikture Pro 1.0.0
   * @param array $input call to action section details.
   */
  function pikture_pro_get_about_temp_portfolio_section_details( $input ) {
    $options = pikture_pro_get_theme_options();

    // Content type.
    $about_temp_portfolio_content_type  = $options['about_temp_portfolio_content_type'];
    $content = array();
    switch ( $about_temp_portfolio_content_type ) {
        case 'demo':
            $demo['title']     = esc_html__( 'Photographer', 'pikture-pro' );
            $demo['sub_title'] = esc_html__( 'POPULAR', 'pikture-pro' );
            $demo['content']   = sprintf( esc_html__( '%1$sPraesent sit amet porta nunc. Aenean nulla ipsum, tempus porta blandit eu, sagittis vel ex. Morbi imperdiet nibh id ipsum finibus convallis. Nulla feugiat vestibulum lacus ut iaculis. Pellentesque consequat nulla vitae ante porttitor elementum. Aenean ac ex vitae nisl condimentum sodales ac ut velit. Nunc vestibulum justo diam, ac elementum neque egestas eget. Aliquam porta ligula non iaculis pellentesque. Sed iaculis tellus egestas metus ornare, ut tempor erat imperdiet.%2$s
            %1$sAmazing photography, great person to work with. Would like to work more in future. Lorem ipsum dolor sit amet tempor neque, Sed iaculis tellus egestas metus ornare, ut tempor erat imperdiet aliquam porta ligula non iaculis pellentesque. %2$s', 'pikture-pro' ), '<p>', '</p>' );
            $demo['img']       = get_template_directory_uri() . '/assets/uploads/portfolio-01.jpg';
            $demo['name']   = esc_html__( 'Meagan Fisher', 'pikture-pro' );
            $demo['position']   = esc_html__( 'UI/UX Designer', 'pikture-pro' );

            // Push to the main array.
            array_push( $content, $demo );
        break;

        case 'custom':
            $custom['title']     = $options['about_temp_portfolio_custom_title'];
            $custom['sub_title'] = $options['about_temp_portfolio_custom_sub_title'];
            $custom['content']   = $options['about_temp_portfolio_custom_content'];
            $custom['img']       = ( isset( $options['about_temp_portfolio_custom_image'] ) ) ? $options['about_temp_portfolio_custom_image'] : '';
            $custom['name'] = ( isset( $options['about_temp_portfolio_custom_name'] ) ) ? $options['about_temp_portfolio_custom_name'] : '';
            $custom['position']   = ( isset( $options['about_temp_portfolio_custom_position'] ) ) ? $options['about_temp_portfolio_custom_position'] : '';

            array_push( $content, $custom );
            $content = array_filter( $content );
        break;

        case 'page':
            if ( isset( $options['about_temp_portfolio_page_id'] ) ) {
                $id = $options['about_temp_portfolio_page_id'];
            }
        break;

        case 'post':
            if ( isset( $options['about_temp_portfolio_post_id'] ) ) {
                $id = $options['about_temp_portfolio_post_id'];
            }
        break;

        default:
        break;
    }
    if ( 'post' === $about_temp_portfolio_content_type || 'page' === $about_temp_portfolio_content_type ) {
        if( ! empty ( $id ) ) {
            // Prepare arguments.
            $args = array(
                'post_type'           => $about_temp_portfolio_content_type,
                'p'                   => $id,
                'ignore_sticky_posts' => true
            );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['sub_title'] = $options['about_temp_portfolio_custom_sub_title'];
                    $page_post['content'] = get_the_content();
                    $page_post['img']       = get_the_post_thumbnail_url();
                    $page_post['name'] = ( isset( $options['about_temp_portfolio_custom_name'] ) ) ? $options['about_temp_portfolio_custom_name'] : '';
                    $page_post['position']   = ( isset( $options['about_temp_portfolio_custom_position'] ) ) ? $options['about_temp_portfolio_custom_position'] : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
                wp_reset_postdata();
            endif;
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// About section content details.
add_filter( 'pikture_pro_filter_about_temp_portfolio_section_details', 'pikture_pro_get_about_temp_portfolio_section_details' );


if ( ! function_exists( 'pikture_pro_render_about_temp_portfolio_section' ) ) :
  /**
   * Start call to action section
   *
   * @return string About content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_about_temp_portfolio_section( $content_details = array() ) {
        $options        = pikture_pro_get_theme_options();
        ?>
        <div id="portfolio" class="clear">
            <?php foreach ($content_details as $content ) : 
                $class = ( empty( $content['img'] ) ) ? 'full-width' : '';
                ?>
                <article class="has-featured-image <?php echo esc_attr( $class ); ?>">

                    <?php if ( ! empty( $content['img'] ) ) : ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['img'] ); ?>')">
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                    

                    <div class="entry-container">
                        <header class="entry-header align-left">
                            <span class="sub-title"><?php echo esc_html( $content['sub_title'] ); ?></span>
                            <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            <div class="seperator"></div>
                        </header><!-- .entry-header -->

                        <div class="entry-content">
                            <?php echo pikture_pro_sanitize_html( $content['content'] ); ?>
                        <div class="position">
                            <h5><?php echo esc_html( $content['name'] ); ?></h5>
                            <span class="designation"><?php echo esc_html( $content['position'] ); ?></span>
                        </div><!-- .position -->
                    </div><!-- .entry-container -->
                </article><!-- .has-featured-image -->
            <?php endforeach; ?>
        </div><!-- #portfolio -->
<?php
    }
endif;