<?php
/**
 * About us template slider section
 *
 * This is the template for the about template slider section
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since 1.0
 */
if ( ! function_exists( 'pikture_pro_add_about_temp_slider_section' ) ) :
  /**
   * Add about template slider section
   *
   *@since Pikture Pro 1.0.0
   */
  function pikture_pro_add_about_temp_slider_section() {
    // Check if about template slider is enabled.
    $options = pikture_pro_get_theme_options();

	if ( ! $options['enable_about_temp_slider'] ){
        return false;
    }

    // Get about template slider section details
    $section_details = array();
    $section_details = apply_filters( 'pikture_pro_filter_about_temp_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render about template slider section now.
    pikture_pro_render_about_temp_slider_section( $section_details );
  }
endif;
add_action( 'pikture_pro_about_us_template', 'pikture_pro_add_about_temp_slider_section', 10 );


if ( ! function_exists( 'pikture_pro_get_about_temp_slider_section_details' ) ) :
  /**
   * about template slider section details.
   *
   * @since Pikture Pro 1.0.0
   * @param array $input about template slider section details.
   */
  function pikture_pro_get_about_temp_slider_section_details( $input ) {
    $options = pikture_pro_get_theme_options();

    // Content type.
    $about_temp_slider_content_type  = $options['about_temp_slider_content_type'];
    $content = array();
    switch ( $about_temp_slider_content_type ) {
        case 'demo':
            for ( $i=1; $i < 4; $i++ ) { 
                $demo['title']     = esc_html__( 'Helen Tran', 'pikture-pro' );
                $demo['sub_title'] = esc_html__( 'Photographer', 'pikture-pro' );
                $demo['content']   = sprintf( esc_html__( '%1$sPraesent sit amet porta nunc. Aenean nulla ipsum, tempus porta blandit eu, sagittis vel ex. Morbi imperdiet nibh id ipsum finibus convallis. Nulla feugiat vestibulum lacus ut iaculis. Pellentesque consequat nulla vitae ante porttitor elementum.%2$s
                %1$sIn porta diam vel leo ornare maximus. Sed aliquam nunc ut lobortis consequat. Donec posuere, lectus in tristique lacinia, purus enim feugiat urna, sit amet iaculis lectus purus vitae mi. Mauris in dictum erat fusce malesuada lacinia ante.%2$s', 'pikture-pro' ), '<p>', '</p>' );
                $demo['img']       = get_template_directory_uri() . '/assets/uploads/slider-01.jpg';

                // Push to the main array.
                array_push( $content, $demo );
            }
        break;

        case 'custom':
            for ( $i=1; $i <= $options['about_temp_slider_num']; $i++ ) {
                $custom['title'] = ( empty( $options['about_temp_slider_custom_title_' . $i ] ) ) ? $options['about_temp_slider_custom_title'] : $options['about_temp_slider_custom_title_' . $i ];
                $custom['sub_title'] = ( empty( $options['about_temp_slider_custom_work_' . $i ] ) ) ? $options['about_temp_slider_custom_work'] : $options['about_temp_slider_custom_work_' . $i ];
                $custom['content'] = ( empty( $options['about_temp_slider_custom_content_' . $i ] ) ) ? $options['about_temp_slider_custom_content'] : $options['about_temp_slider_custom_content_' . $i ];
                $custom['img'] = ( empty( $options['about_temp_slider_custom_image_' . $i ] ) ) ? $options['about_temp_slider_custom_image'] : $options['about_temp_slider_custom_image_' . $i ];

                array_push( $content, $custom );
                $content = array_filter( $content );
            }
        break;

        case 'page':
            $id_arr = array();
            for ( $i=1; $i <= $options['about_temp_slider_num']; $i++ ) {
                if ( isset( $options['about_temp_slider_page_id_' . $i ] ) ) {
                    array_push( $id_arr, $options['about_temp_slider_page_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id_arr = array_filter( $id_arr );
        break;

        case 'post':
            $id_arr = array();
            for ( $i=1; $i <= $options['about_temp_slider_num']; $i++ ) {
                if ( isset( $options['about_temp_slider_post_id_' . $i ] ) ) {
                    array_push( $id_arr, $options['about_temp_slider_post_id_' . $i ] );
                }
            }
            // Remove any empty values.
            $id_arr = array_filter( $id_arr );
        break;

        default:
        break;
    }
    if ( 'post' === $about_temp_slider_content_type || 'page' === $about_temp_slider_content_type ) {

        if( ! empty ( $id_arr ) ) {
            // Prepare arguments.
            $args = array(
                'post_type'           => $about_temp_slider_content_type,
                'post__in'            => $id_arr,
                'ignore_sticky_posts' => true,
                'orderby'             => 'post__in',
                'posts_per_page'      => $options['about_temp_slider_num']
            );

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']    = get_the_title();
                    $page_post['sub_title'] = '';
                    $page_post['content']  = get_the_content();
                    $page_post['img']      = get_the_post_thumbnail_url();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
                wp_reset_postdata();
            endif;
        }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// About template slider section content details.
add_filter( 'pikture_pro_filter_about_temp_slider_section_details', 'pikture_pro_get_about_temp_slider_section_details' );


if ( ! function_exists( 'pikture_pro_render_about_temp_slider_section' ) ) :
  /**
   * Start about template slider section
   *
   * @return string About template slider content
   * @since Pikture Pro 1.0.0
   *
   */
   function pikture_pro_render_about_temp_slider_section( $content_details = array() ) {
        $options = pikture_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
    	<div id="about-slider">
    		<div class="regular" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": false, "speed": 800, "dots": true, "arrows":true, "autoplay": true, "fade": false, "draggable": true }'>
                <?php foreach ( $content_details as $content ) : ?>
        		  	<div class="slider-item" style="background-image: url('<?php echo esc_url( $content['img'] ); ?>');">

        		  		<div class="container">
                            <div class="slider-content">
                                <div class="flex">
                                    <header class="entry-header">
        			                    <span class="sub-title"><?php echo esc_html( $content['sub_title'] ); ?></span>
        			                    <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
        			                    <div class="seperator"></div>
        			                </header><!-- .entry-header -->

        			                <div class="entry-content">
        			                	<?php echo wp_kses_post( $content['content'] ); ?>
        			                </div><!-- .entry-content -->
                                </div><!-- .flex -->
                            </div><!-- .slider-content -->

                       	</div><!-- .container -->
                    </div><!-- .slider-item -->
                <?php endforeach; ?>

    		</div><!-- .regular -->
    	</div><!-- #about-slider -->
<?php
    }
endif;