<?php
/**
 * Tab widget
 *
 * @package Theme Palace
 * @subpackage Pikture Pro
 * @since Pikture Pro 1.0.0
*/
if ( !class_exists('Pikture_Pro_Wpt_Widget') ) {
	/**
	 * Tab Widget class.
	 *
	 */
	class Pikture_Pro_Wpt_Widget extends WP_Widget {
		function __construct() {
	        
	        // add image sizes and load language file
	        add_action( 'init', array(&$this, 'wpt_init') );
	        
			// ajax functions
			add_action('wp_ajax_wpt_widget_content', array(&$this, 'daily_insight_pro_ajax_wpt_widget_content'));
			add_action('wp_ajax_nopriv_wpt_widget_content', array(&$this, 'daily_insight_pro_ajax_wpt_widget_content'));
	        
			$widget_ops = array( 'classname' => 'widget_wpt widget_tab', 'description' => esc_html__('Display recent posts, comments, and tags in tabbed format.', 'pikture-pro'));
			$control_ops = array('width' => 300, 'height' => 350);
			parent::__construct('tp-wpt-widget', esc_html__('TP: Tab Widget', 'pikture-pro'), $widget_ops, $control_ops);
	    }	
	    
	    function wpt_init() {	        
	        add_image_size( 'wp_review_small', 65, 65, true ); // small thumb
	        add_image_size( 'wp_review_large', 320, 240, true ); // large thumb
	    }
	    	
		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, array( 
				'title'	=> '',
				'tabs' => array('recent' => 1, 'comments' => 1, 'tags' => 0), 
				'tab_order' => array('recent' => 1, 'comments' => 2, 'tags' => 3), 
				'allow_pagination' => 1, 
				'post_num' => '5', 
				'comment_num' => '5', 
				'show_thumb' => 1, 
				'thumb_size' => 'small', 
				'show_date' => 1, 
				'show_excerpt' => 0, 
				'excerpt_length' => apply_filters( 'wpt_excerpt_length_default', '15' ), 
				'show_comment_num' => 0, 
				'show_avatar' => 1, 
				'title_length' => apply_filters( 'wpt_title_length_default', '5' ) ,
			) );
			
			extract($instance);

			?>
			<span><b><?php esc_html_e('Make some changes and then click on save button to view changes', 'pikture-pro' ); ?></b></span>
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'pikture-pro' ); ?></label>
				<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
			</p>
			<span><b><?php esc_html_e( 'Leave blank to hide title', 'pikture-pro'); ?></b></span>
	        <div class="wpt_options_form">
	        
	        <h4><?php esc_html_e('Select Tabs', 'pikture-pro'); ?></h4>
	        
			<div class="wpt_select_tabs">
				<label class="alignleft" style="display: block; width: 50%; margin-bottom: 5px;" for="<?php echo esc_attr( $this->get_field_id("tabs") ); ?>_recent">
					<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("tabs") ); ?>_recent" name="<?php echo esc_attr( $this->get_field_name("tabs") ); ?>[recent]" value="1" <?php if (isset($tabs['recent'])) { checked( 1, $tabs['recent'], true ); } ?> />		
					<?php esc_html_e( 'Recent Tab', 'pikture-pro'); ?>
				</label>
				<label class="alignleft" style="display: block; width: 50%;" for="<?php echo esc_attr( $this->get_field_id("tabs") ); ?>_comments">
					<input type="checkbox" class="checkbox wpt_enable_comments" id="<?php echo esc_attr( $this->get_field_id("tabs") ); ?>_comments" name="<?php echo esc_attr( $this->get_field_name("tabs") ); ?>[comments]" value="1" <?php if (isset($tabs['comments'])) { checked( 1, $tabs['comments'], true ); } ?> />
					<?php esc_html_e( 'Comments Tab', 'pikture-pro'); ?>
				</label>
				<label class="alignleft" style="display: block; width: 50%;" for="<?php echo esc_attr( $this->get_field_id("tabs") ); ?>_tags">
					<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("tabs") ); ?>_tags" name="<?php echo esc_attr( $this->get_field_name("tabs") ); ?>[tags]" value="1" <?php if (isset($tabs['tags'])) { checked( 1, $tabs['tags'], true ); } ?> />
					<?php esc_html_e( 'Tags Tab', 'pikture-pro'); ?>
				</label>
			</div>
	        <div class="clear"></div>
	        
	        <h4 class="wpt_tab_order_header"><a href="#"><?php esc_html_e('Tab Order', 'pikture-pro'); ?></a></h4>
	        <div class="wpt_tab_order" style="display: none;">
	        <span><b><?php esc_html_e( 'Small number will get heigher priority ', 'pikture-pro' ); ?></b></span>
	            
	            <label class="alignleft" for="<?php echo esc_attr( $this->get_field_id('tab_order') ); ?>_recent" style="width: 50%;">
					<input id="<?php echo esc_attr( $this->get_field_id('tab_order') ); ?>_recent" name="<?php echo esc_attr( $this->get_field_name('tab_order') ); ?>[recent]" type="number" min="1" step="1" value="<?php echo absint( $tab_order['recent'] ); ?>" style="width: 48px;" />
	                <?php esc_html_e('Recent', 'pikture-pro'); ?>
	            </label>
	            <label class="alignleft" for="<?php echo esc_attr( $this->get_field_id('tab_order') ); ?>_comments" style="width: 50%;">
					<input id="<?php echo esc_attr( $this->get_field_id('tab_order') ); ?>_comments" name="<?php echo esc_attr( $this->get_field_name('tab_order') ); ?>[comments]" type="number" min="1" step="1" value="<?php echo absint( $tab_order['comments'] ); ?>" style="width: 48px;" />
				    <?php esc_html_e('Comments', 'pikture-pro'); ?>
	            </label>
	            <label class="alignleft" for="<?php echo esc_attr( $this->get_field_id('tab_order') ); ?>_tags" style="width: 50%;">
					<input id="<?php echo esc_attr( $this->get_field_id('tab_order') ); ?>_tags" name="<?php echo esc_attr( $this->get_field_name('tab_order') ); ?>[tags]" type="number" min="1" step="1" value="<?php echo absint( $tab_order['tags'] ); ?>" style="width: 48px;" />
				    <?php esc_html_e('Tags', 'pikture-pro'); ?>
	            </label>
	        </div>
			<div class="clear"></div>
	        
	        <h4 class="wpt_advanced_options_header"><a href="#"><?php esc_html_e('Advanced Options', 'pikture-pro'); ?></a></h4>
	        
	        <div class="wpt_advanced_options" style="display: none;">
	        <p>
				<label for="<?php echo esc_attr( $this->get_field_id("allow_pagination") ); ?>">				
					<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("allow_pagination") ); ?>" name="<?php echo esc_attr( $this->get_field_name("allow_pagination") ); ?>" value="1" <?php if (isset($allow_pagination)) { checked( 1, $allow_pagination, true ); } ?> />
					<?php esc_html_e( 'Allow pagination', 'pikture-pro'); ?>
				</label>
			</p>
			
			<div class="wpt_post_options">

			<span><b><?php esc_html_e( 'Recent Posts Options','pikture-pro' );?></b></span>
	        <p>
				<label for="<?php echo esc_attr( $this->get_field_id('post_num') ); ?>"><?php esc_html_e('Number of posts to show:', 'pikture-pro'); ?>
					<br />
					<input id="<?php echo esc_attr( $this->get_field_id('post_num') ); ?>" name="<?php echo esc_attr( $this->get_field_name('post_num') ); ?>" type="number" min="1" step="1" value="<?php echo absint( $post_num ); ?>" />
				</label>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id('title_length') ); ?>"><?php esc_html_e('Title length (words):', 'pikture-pro'); ?>
					<br />
					<input id="<?php echo esc_attr( $this->get_field_id('title_length') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title_length') ); ?>" type="number" min="1" step="1" value="<?php echo absint( $title_length ); ?>" />
				</label>
			</p>
			
			<p>
				<label for="<?php echo esc_attr( $this->get_field_id("show_thumb") ); ?>">
					<input type="checkbox" class="checkbox wpt_show_thumbnails" id="<?php echo esc_attr( $this->get_field_id("show_thumb") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_thumb") ); ?>" value="1" <?php if (isset($show_thumb)) { checked( 1, $show_thumb, true ); } ?> />
					<?php esc_html_e( 'Show post thumbnails', 'pikture-pro'); ?>
				</label>
			</p>   
			
			<p class="wpt_thumbnail_size"<?php echo (empty($show_thumb) ? ' style="display: none;"' : ''); ?>>
				<label for="<?php echo esc_attr( $this->get_field_id('thumb_size') ); ?>"><?php esc_html_e('Thumbnail size:', 'pikture-pro'); ?></label> 
				<select id="<?php echo esc_attr( $this->get_field_id('thumb_size') ); ?>" name="<?php echo esc_attr( $this->get_field_name('thumb_size') ); ?>" style="margin-left: 12px;">
					<option value="small" <?php selected($thumb_size, 'small', true); ?>><?php esc_html_e('Small', 'pikture-pro'); ?></option>
					<option value="large" <?php selected($thumb_size, 'large', true); ?>><?php esc_html_e('Large', 'pikture-pro'); ?></option>    
				</select>       
			</p>	
			
			<p>			
				<label for="<?php echo esc_attr( $this->get_field_id("show_date") ); ?>">	
					<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_date") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_date") ); ?>" value="1" <?php if (isset($show_date)) { checked( 1, $show_date, true ); } ?> />	
					<?php esc_html_e( 'Show post date', 'pikture-pro'); ?>	
				</label>	
			</p>
	        
			<p>		
				<label for="<?php echo esc_attr( $this->get_field_id("show_comment_num") ); ?>">		
					<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_comment_num") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_comment_num") ); ?>" value="1" <?php if (isset($show_comment_num)) { checked( 1, $show_comment_num, true ); } ?> />	
					<?php esc_html_e( 'Show number of comments', 'pikture-pro'); ?>		
				</label>	
			</p>    
			
			<p>			
				<label for="<?php echo esc_attr( $this->get_field_id("show_excerpt") ); ?>">	
					<input type="checkbox" class="checkbox wpt_show_excerpt" id="<?php echo esc_attr( $this->get_field_id("show_excerpt") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_excerpt") ); ?>" value="1" <?php if (isset($show_excerpt)) { checked( 1, $show_excerpt, true ); } ?> />
					<?php esc_html_e( 'Show post excerpt', 'pikture-pro'); ?>
				</label>		
			</p>
			
			<p class="wpt_excerpt_length"<?php echo (empty($show_excerpt) ? ' style="display: none;"' : ''); ?>>
				<label for="<?php echo esc_attr( $this->get_field_id('excerpt_length') ); ?>">
					<?php esc_html_e('Excerpt length (words):', 'pikture-pro'); ?>   
					<br />
					<input type="number" min="1" step="1" id="<?php echo esc_attr( $this->get_field_id('excerpt_length') ); ?>" name="<?php echo esc_attr( $this->get_field_name('excerpt_length') ); ?>" value="<?php echo absint( $excerpt_length ); ?>" />
				</label>
			</p>	
			  
			</div>
	        <div class="clear"></div>
	        
	        <div class="wpt_comment_options"<?php echo (empty($tabs['comments']) ? ' style="display: none;"' : ''); ?>>
			
	        <span><b><?php esc_html_e( 'Comments Options','pikture-pro' );?></b></span>
	        <p>
				<label for="<?php echo esc_attr( $this->get_field_id('comment_num') ); ?>">
					<?php esc_html_e('Number of comments on Comments Tab:', 'pikture-pro'); ?>
					<br />
					<input type="number" min="1" step="1" id="<?php echo esc_attr( $this->get_field_id('comment_num') ); ?>" name="<?php echo esc_attr( $this->get_field_name('comment_num') ); ?>" value="<?php echo absint( $comment_num ); ?>" />
				</label>			
			</p>      
			
			<p>			
				<label for="<?php echo esc_attr( $this->get_field_id("show_avatar") ); ?>">			
					<input type="checkbox" class="checkbox" id="<?php echo esc_attr( $this->get_field_id("show_avatar") ); ?>" name="<?php echo esc_attr( $this->get_field_name("show_avatar") ); ?>" value="1" <?php if (isset($show_avatar)) { checked( 1, $show_avatar, true ); } ?> />
					<?php esc_html_e( 'Show avatars on Comments Tab', 'pikture-pro'); ?>	
				</label>	
			</p>
			</div><!-- .wpt_comment_options -->
			</div><!-- .wpt_advanced_options -->
			</div><!-- .wpt_options_form -->
			<?php 
		}	
		
		function update( $new_instance, $old_instance ) {	
			$instance                     = $old_instance;
			$instance['title']            = sanitize_text_field( $new_instance['title'] );    
			$instance['tabs']             = daily_insight_pro_sanitize_tabs( $new_instance['tabs'] );  
			$instance['tab_order']        = daily_insight_pro_sanitize_tabs_order( $new_instance['tab_order'] );  
			$instance['allow_pagination'] = pikture_pro_sanitize_checkbox( $new_instance['allow_pagination'] );	
			$instance['post_num']         = absint( $new_instance['post_num'] );	
			$instance['title_length']     = absint( $new_instance['title_length'] );	
			$instance['comment_num']      = absint( $new_instance['comment_num'] );		
			$instance['show_thumb']       = pikture_pro_sanitize_checkbox( $new_instance['show_thumb'] );     
			$instance['thumb_size']       = in_array( $new_instance['thumb_size'] , array( 'small', 'large')) ? $new_instance['thumb_size'] : '';		
			$instance['show_date']        = pikture_pro_sanitize_checkbox( $new_instance['show_date'] );    
			$instance['show_excerpt']     = pikture_pro_sanitize_checkbox( $new_instance['show_excerpt'] );  
			$instance['excerpt_length']   = absint( $new_instance['excerpt_length'] );	
			$instance['show_comment_num'] = pikture_pro_sanitize_checkbox( $new_instance['show_comment_num'] );  
			$instance['show_avatar']      = pikture_pro_sanitize_checkbox( $new_instance['show_avatar'] );	
			return $instance;
		}	
		function widget( $args, $instance ) {	
			extract($args);     
			extract($instance);     
			if (empty($tabs)) $tabs = array('recent' => 1, 'comment' => 1 );    
			$tabs_count = count($tabs);     
			if ($tabs_count <= 1) {       
				$tabs_count = 1;       
			} elseif($tabs_count == 2 ) {   
				$tabs_count = 2;      
			} else {
				$tabs_count = 3;
			}

			if( empty($tab_order)) $tab_order = array('recent' => 1, 'comments' => 2, 'tags' => 3 ); 
	        
	        $available_tabs = array(
	            'recent' 	=> esc_html__('Recent', 'pikture-pro'), 
	            'comments'  => esc_html__('Comments', 'pikture-pro'), 
	            'tags' 		=> esc_html__('Tags', 'pikture-pro')
	        );
	            
	        array_multisort( $tab_order, $available_tabs );

	        $title             = !empty( $title ) ? $title : '';

	        $title             = apply_filters( 'widget_title', $title, $instance, $this->id_base );
			?>	
			<?php echo $before_widget;
			if ( ! empty( $title ) ) {
				echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
			} 
			?>	
			<div class="wpt_widget_content" id="<?php echo esc_attr( $widget_id ); ?>_content" data-widget-number="<?php echo esc_attr( $this->number ); ?>">	
				<ul class="wpt-tabs <?php echo 'has-'. absint( $tabs_count ) .'-'; ?>tabs">
	                <?php foreach ($available_tabs as $tab => $label) { ?>
	                    <?php if (!empty($tabs[$tab])): ?>
	                        <li class="tab_title"><a href="#" id="<?php echo esc_attr( $tab ); ?>-tab"><?php echo esc_html( $label ); ?></a></li>	
	                    <?php endif; ?>
	                <?php } ?> 
				</ul> <!--end .tabs-->	
				<div class="clear"></div>  
				<div class="inside">            
					<?php if (!empty($tabs['recent'])): ?>	
						<div id="recent-tab-content" class="tab-content"> 		 
						</div> <!--end #recent-tab-content-->		
					<?php endif; ?>                     
					<?php if (!empty($tabs['comments'])): ?>      
						<div id="comments-tab-content" class="tab-content"> 	
							<ul>                    		
							</ul>		
						</div> <!--end #comments-tab-content-->     
					<?php endif; ?>            
					<?php if (!empty($tabs['tags'])): ?>       
						<div id="tags-tab-content" class="tab-content"> 	
							<ul>                    	
							</ul>			 
						</div> <!--end #tags-tab-content-->  
					<?php endif; ?>
					<div class="clear"></div>
				</div> <!--end .inside -->
				<div class="clear"></div>
			</div><!--end #tabber -->
			<?php    
			// inline script 
			// to support multiple instances per page with different settings   
			
			unset($instance['tabs'], $instance['tab_order']); // unset unneeded  
			?>  
			<script type="text/javascript">  
				jQuery(function($) {    
					$('#<?php echo esc_attr( $widget_id ); ?>_content').data('args', <?php echo json_encode($instance); ?>);  
				});  
			</script>  
			<?php echo $after_widget; ?>
			<?php 
		}  
		 
		function daily_insight_pro_ajax_wpt_widget_content( $args, $number ) {     
			$tab    = wp_unslash( $_POST['tab'] );       
			$args   = wp_unslash( $_POST ['args'] );  
			$number = intval( wp_unslash( $_POST['widget_number'] ) );
			$page   = intval( wp_unslash( $_POST['page'] ) ); 
			if ($page < 1)        
				$page = 1;

			if ( !is_array( $args ) || empty( $args ) ) { // json_encode() failed
				$wpt_widgets = new wpt_widget();
				$settings = $wpt_widgets->get_settings();

				if ( isset( $settings[ $number ] ) ) {
					$args = $settings[ $number ];
				} else {
					die( esc_html__('Unable to load tab content', 'pikture-pro') );
				}
			}                                                                                                                                    
	    	
	        
			// sanitize args		
			$post_num = (empty($args['post_num']) ? 5 : intval($args['post_num']));    
			if ($post_num > 20 || $post_num < 1) { // max 20 posts
				$post_num = 5;   
			}      
			$comment_num = (empty($args['comment_num']) ? 5 : intval($args['comment_num']));   
			if ($comment_num > 20 || $comment_num < 1) {  
				$comment_num = 5;    
			}       
			$show_thumb = !empty($args['show_thumb']) ? $args['show_thumb'] : 'true';
			$thumb_size = $args['thumb_size'];
	        if ($thumb_size != 'small' && $thumb_size != 'large') {
	            $thumb_size = 'small'; // default
	        }
			$show_date = !empty($args['show_date']) ? $args['show_date'] : 'true';     
			$show_excerpt = !empty($args['show_excerpt']) ? $args['show_excerpt'] : 'true';  
			$excerpt_length = intval($args['excerpt_length']);
	        if ($excerpt_length > 50 || $excerpt_length < 1) {  
				$excerpt_length = 10;   
			}   
			$show_comment_num = !empty($args['show_comment_num']) ? $args['show_comment_num'] : 'true';  
			$show_avatar = !empty($args['show_avatar']) ? $args['show_avatar'] : 'true';   
			$allow_pagination = !empty($args['allow_pagination']) ? $args['allow_pagination'] : 'false';

			$title_length = ! empty($args['title_length']) ? $args['title_length'] : apply_filters( 'wpt_title_length_default', '5' );
	        
			/* ---------- Tab Contents ---------- */    
			switch ($tab) {           
	            
				/* ---------- Recent Posts ---------- */      
				case "recent":           
					?>         
					<ul>			
						<?php              
						$recent = new WP_Query('posts_per_page='. $post_num .'&orderby=post_date&order=desc&post_status=publish&paged='. $page);       
						$last_page = $recent->max_num_pages;      
						while ($recent->have_posts()) : $recent->the_post();    
							?>						         
							<li>
								<?php if ( $show_thumb == 'true' ) : ?>					
									<div class="wpt_thumbnail wpt_thumb_<?php echo esc_attr( $thumb_size ); ?>">	
	                                    <a title="<?php the_title_attribute(); ?>" href="<?php the_permalink() ?>">		
	    									<?php if(has_post_thumbnail()): ?>	
	    										<?php the_post_thumbnail('wp_review_'.$thumb_size, array('title' => '')); ?>		
	    									<?php endif; ?>
	                                    </a>
									</div>				
								<?php endif; ?>					
								<div class="entry-title"><a title="<?php the_title_attribute(); ?>" href="<?php the_permalink() ?>"><?php echo esc_html( $this->post_title( $title_length ) ); ?></a></div>		
								<?php if ( $show_date == 'true' || $show_comment_num == 'true' ) : ?>			
									<div class="wpt-postmeta">										
										<?php if ( $show_date == 'true' ) : ?>						
											<time><?php the_time('F j, Y'); ?></time>						
										<?php endif; ?>								
										<?php if ( $show_date == 'true' && $show_comment_num == 'true') : ?>		
											&bull; 										
										<?php endif; ?>								
										<?php if ( $show_comment_num == 'true' ) : ?>	
											<?php echo comments_number(esc_html__('No Comment','pikture-pro'), esc_html__('One Comment','pikture-pro'), '<span class="comments-number">%</span> '.esc_html__('Comments','pikture-pro'));?>									
										<?php endif; ?>		
									</div> <!--end .entry-meta--> 		
								<?php endif; ?>
	                            
	                            <?php if ( $show_excerpt == 'true' ) : ?>	
	                                <div class="wpt_excerpt">
	                                    <p><?php echo wp_kses_post( $this->excerpt($excerpt_length) ); ?></p>
	                                </div>
	                            <?php endif; ?>	
	                            	
								<div class="clear"></div>		
							</li>				
						<?php endwhile; wp_reset_postdata(); ?>		
					</ul>
	                <div class="clear"></div>
					<?php if ($allow_pagination  == 'true') : ?>       
						<?php $this->tab_pagination($page, $last_page); ?>    
					<?php endif; ?>                 
					<?php       
				break;     
	            
				/* ---------- Latest Comments ---------- */        
				case "comments":         
					?>          
					<ul>            
						<?php              
						$no_comments = false;         
						$avatar_size = 65;            
						$comment_length = 90; // max length for comments   
						$comment_args = apply_filters(
							'wpt_comments_tab_args',
							array(
								'type' => 'comments',
								'status' => 'approve'
							)
						);     
						$comments_total = new WP_Comment_Query();
						$comments_total_number = $comments_total->query( array_merge( array('count' => 1 ), $comment_args ) );
						$last_page = (int) ceil($comments_total_number / $comment_num);
						$comments_query = new WP_Comment_Query();
						$offset = ($page-1) * $comment_num;
						$comments = $comments_query->query( array_merge( array( 'number' => $comment_num, 'offset' => $offset ), $comment_args ) );
						if ( $comments ) : foreach ( $comments as $comment ) : ?>       
							<li>          
								<?php if ($show_avatar == 'true') : ?>                       
									<div class="wpt_avatar">
	                                    <a href="<?php echo esc_url( get_comment_link($comment->comment_ID) ); ?>">
											<?php echo get_avatar( $comment->comment_author_email, $avatar_size ); ?>     
	                                    </a>                               
									</div>                   
								<?php endif; ?>              
								<div class="wpt_comment_meta">
	                                <a href="<?php echo esc_url( get_comment_link($comment->comment_ID) ); ?>">   
										<span class="wpt_comment_author"><?php echo esc_html( get_comment_author( $comment->comment_ID ) ); ?> </span> - <span class="wpt_comment_post"><?php echo esc_html( get_the_title($comment->comment_post_ID) ); ?></span>                   
								    </a>
	                            </div>                   
								<div class="wpt_comment_content">          
									<p><?php echo wp_kses_post( $this->truncate(strip_tags(apply_filters( 'get_comment_text', $comment->comment_content )), $comment_length) );?></p>
								</div>                                   
								<div class="clear"></div>      
							</li>           
						<?php endforeach; else : ?>           
							<li>                   
								<div class="no-comments"><?php esc_html_e('No comments yet.', 'pikture-pro'); ?></div>        
							</li>                             
							<?php $no_comments = true; 
						endif; ?>       
					</ul>       
					<?php if ($allow_pagination == 'true' && !$no_comments) : ?>           
						<?php $this->tab_pagination($page, $last_page); ?>      
					<?php endif; ?>                     
					<?php           
				break;             
	            
				/* ---------- Tags ---------- */   
				case "tags":        
					?>           
					<ul>         
						<?php        
						$tags = get_tags(array('get'=>'all'));             
						if($tags) {               
							foreach ($tags as $tag): ?>    
								<li><a href="<?php echo esc_url( get_term_link($tag) ); ?>"><?php echo esc_html( $tag->name ); ?></a></li>           
								<?php            
							endforeach;       
						} else {          
							esc_html_e('No tags created.', 'pikture-pro');           
						}            
						?>           
					</ul>            
					<?php            
				break;            
			}              
			die(); // required to return a proper result  
		}    
	    function tab_pagination($page, $last_page) {  
			?>   
			<div class="wpt-pagination">     
				<?php if ($page > 1) : ?>               
					<a href="#" class="previous"><span><?php esc_html_e('&laquo; Previous', 'pikture-pro'); ?></span></a>      
				<?php endif; ?>        
				<?php if ($page != $last_page) : ?>     
					<a href="#" class="next"><span><?php esc_html_e('Next &raquo;', 'pikture-pro'); ?></span></a>      
				<?php endif; ?>          
			</div>                   
			<div class="clear"></div>
			<input type="hidden" class="page_num" name="page_num" value="<?php echo absint( $page ); ?>" />    
			<?php   
		}
	    
	    function excerpt($limit = 10) {
	    	  $limit++;
	          $excerpt = explode(' ', get_the_excerpt(), $limit);
	          if (count($excerpt)>=$limit) {
	            array_pop($excerpt);
	            $excerpt = implode(" ",$excerpt).'...';
	          } else {
	            $excerpt = implode(" ",$excerpt);
	          }
	          $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
	          return $excerpt;
	    }
	    function post_title($limit = 10) {
	    	  $limit++;
	          $title = explode(' ', get_the_title(), $limit);
	          if (count($title)>=$limit) {
	            array_pop($title);
	            $title = implode(" ",$title).'...';
	          } else {
	            $title = implode(" ",$title);
	          }
	          return $title;
	    }
	    function truncate($str, $length = 24) {
	        if (mb_strlen($str) > $length) {
	            return mb_substr($str, 0, $length).'...';
	        } else {
	            return $str;
	        }
	    }
	}
}